/*
 * mpl-core.c
 *
 * by Alexander Zhirov (alexander@zhirov.kz)
 * Telegram @alexanderzhirov
 */

#include "mpl-lib.h"
#include "mpl-core.h"

#include <regex.h>
#include <dirent.h>
#include <fcntl.h>

int device_path(const MPL_MODEM *modem)
{
    DIR *dir;
    struct dirent *ent;
    regex_t regex;
    const char *pattern = "^ttyUSB[0-9]*$";

    int ret = regcomp(&regex, pattern, REG_EXTENDED);
    if (ret != 0)
    {
        printf("Failed to compile regular expression\n");
        return 1;
    }

    dir = opendir(modem->path);
    if (dir == NULL)
    {
        printf("Failed to open directory: %s\n", modem->path);
        regfree(&regex);
        return 1;
    }

    while ((ent = readdir(dir)) != NULL)
    {
        if (strcmp(ent->d_name, ".") == 0 || strcmp(ent->d_name, "..") == 0)
        {
            continue;
        }

        ret = regexec(&regex, ent->d_name, 0, NULL, 0);

        if (ret == 0)
        {
            printf("Found a file matching the pattern: %s\n", ent->d_name);

            char *path = (char *)calloc(strlen(MPL_DEV_PATH) + strlen(ent->d_name) + 1, sizeof(char));
            strcpy(path, MPL_DEV_PATH);
            strcat(path, ent->d_name);

            int fd = open(path, O_RDWR);
            if (fd < 0)
            {
                printf("Не удалось открыть USB устройство.\n");
                free(path);
                continue;
            }

            char *tty = ttyname(fd);
            close(fd);

            if (tty != NULL)
            {
                printf("%s устройство tty: %s\n", modem->action ? "Добавлено" : "Удалено", tty);

                // if (!num)
                //     print_imei(tty);
            }
            else
            {
                printf("Устройство tty не найдено\n");
            }
        }
        else if (ret != REG_NOMATCH)
        {
            printf("Failed to apply regular expression\n");
        }
    }

    regfree(&regex);
    closedir(dir);

    return 0;
}
